﻿''' <summary>
''' Klasse für das Rubberband.Finished-Event
''' </summary>
Public Class RubberBandEventArgs
    Inherits EventArgs

    Private _Buttons As MouseButtons
    Private _Area As Rectangle
    Private _StartedAt As Point
    Private _EndedAt As Point

    ''' <summary>
    ''' Liefert ein Point-Objekt mit den Koordiaten an dem Rubberband gestartet 
    '''  wurde
    ''' </summary>
    ''' <remarks></remarks>
    Public ReadOnly Property StartedAt() As Point
        Get
            Return _StartedAt
        End Get
    End Property

    ''' <summary>
    ''' Liefert ein Point-Objekt mit den Koordinaten an dem Rubberband beendet 
    '''  wurde
    ''' </summary>
    ''' <remarks></remarks>
    Public ReadOnly Property EndedAt() As Point
        Get
            Return _EndedAt
        End Get
    End Property

    ''' <summary>
    ''' Initialisert eine neue Instanz von RubberbandEventArgs
    ''' </summary>
    ''' <param name="StartedAt">
    '''  ein Point-Objekt mit den Koordinaten, an denen Rubberband 
    '''  gestartet wurde
    ''' </param>
    ''' <param name="EndedAt">
    '''  ein Point-Objekt mit den Koordinaten an denen Rubberband beendet wurde
    ''' </param>
    ''' <param name="Button">
    '''  ein Wert der die Maustaste/n angibt mit denen Rubberband gestartet wurde
    '''</param>
    Public Sub New(ByVal StartedAt As Point, ByVal EndedAt As Point, _
                   ByVal Button As MouseButtons)
        MyBase.New()
        _StartedAt = StartedAt
        _EndedAt = EndedAt
        _Area = NormalizedRectangle()
        _Buttons = Buttons
    End Sub

    ''' <summary>
    ''' Liefert einen Wert der die Maustaste/n angibt mit denen Rubberband 
    '''  gestartet wurde 
    ''' </summary>
    Public ReadOnly Property Buttons() As MouseButtons
        Get
            Return _Buttons
        End Get
    End Property

    ''' <summary>
    ''' Liefert ein normalisiertes Rectangle-Objekt mit den Koordinaten des 
    ''' ausgewählten Bereichs
    ''' </summary>
    Public ReadOnly Property Area() As Rectangle
        Get
            Return _Area
        End Get
    End Property

    ''' <summary>
    ''' Liefert ein normalisiertes Rectangle berechnet aus StartedAt und EndedAt
    ''' </summary>
    ''' <returns>Ein normalisiertes Rectangle-Objekt</returns>
    ''' <remarks>
    '''  Erstellt ein Rectangle dessen Location-Eigenschaft die linke obere Ecke 
    '''  bestimmt und positive Werte für Width und Height enthält
    ''' </remarks>
    Private Function NormalizedRectangle() As Rectangle
        Dim pt1 As New Point
        Dim pt2 As New Point

        If (_StartedAt.X - _EndedAt.X) < 0 Then
            pt1.X = _StartedAt.X
            pt2.X = _EndedAt.X
        Else
            pt1.X = _EndedAt.X
            pt2.X = _StartedAt.X
        End If
        If (_StartedAt.Y - _EndedAt.Y) < 0 Then
            pt1.Y = _StartedAt.Y
            pt2.Y = _EndedAt.Y
        Else
            pt1.Y = _EndedAt.Y
            pt2.Y = _StartedAt.Y
        End If

        Return New Rectangle(pt1, New Size(pt2.X - pt1.X, pt2.Y - pt1.Y))
    End Function
End Class
